@@ -42,6 +42,6 @@ export LIBRARY_PATH
 export LD_LIBRARY_PATH
 export DYLD_LIBRARY_PATH
 
-python setup.py bdist_wheel && \
-	$fixlib dist/$wheel || true && \
-	pip install -U dist/$wheel
+python setup.py bdist_wheel || exit 1
+$fixlib dist/$wheel || exit 1
+pip install --upgrade --force-reinstall dist/$wheel || exit 1
