@@ -5,14 +5,9 @@
 """Alleged River Cipher 4 cipher (ARC4 or ARCFOUR) designed in 1987
 at RSA Security."""
 
-import sys
+from __future__ import annotations
 
-if sys.version_info < (3, 8):
-    from typing_extensions import Final, Literal
-else:
-    from typing import Final, Literal
-
-from typing import Optional, Union
+from typing import Final, Literal, Optional, Union
 
 from mbedtls.exceptions import TLSError
 
