@@ -4,14 +4,9 @@
 
 """Blowfish cipher designed by Bruce Schneier in 1993."""
 
-import sys
+from __future__ import annotations
 
-if sys.version_info < (3, 8):
-    from typing_extensions import Final, Literal
-else:
-    from typing import Final, Literal
-
-from typing import Optional, Union
+from typing import Final, Literal, Optional, Union
 
 from mbedtls.exceptions import TLSError
 
@@ -50,6 +45,6 @@ def new(
     if mode_ not in {Mode.CBC, Mode.CFB, Mode.CTR, Mode.ECB}:
         raise TLSError(msg="unsupported mode %r" % mode_)
     name = (
-        "BLOWFISH-%s%s" % (mode_.name, "64" if mode_ is Mode.CFB else "")
+        "BLOWFISH-{}{}".format(mode_.name, "64" if mode_ is Mode.CFB else "")
     ).encode("ascii")
     return Cipher(name, key, mode_, iv)
