@@ -5,14 +5,9 @@
 """Data Encryption Standard (DES) cipher developed by IBM
 in the 70's."""
 
-import sys
+from __future__ import annotations
 
-if sys.version_info < (3, 8):
-    from typing_extensions import Final, Literal
-else:
-    from typing import Final, Literal
-
-from typing import Optional, Union
+from typing import Final, Literal, Optional, Union
 
 from mbedtls.exceptions import TLSError
 
