@@ -88,7 +88,7 @@ class TestECPoint:
     def xyz(self, request: Any) -> Tuple[int, int, int]:
         return request.param  # type: ignore[no-any-return]
 
-    @pytest.fixture()
+    @pytest.fixture
     def point(self, xyz: Tuple[int, int, int]) -> ECPoint:
         return ECPoint(*xyz)
 
@@ -173,7 +173,6 @@ class TestCipher:
         assert pem.startswith(f"-----BEGIN {cipher_tag} PRIVATE KEY-----\n")
         assert pem.endswith(f"-----END {cipher_tag} PRIVATE KEY-----\n")
         assert pem == str(cipher)
-        assert pem == cipher.to_PEM().private
         assert cipher == type(cipher).from_PEM(pem)
 
     @pytest.mark.parametrize(
@@ -194,6 +193,8 @@ class TestCipher:
 
         other = copy(cipher)
         other = type(cipher).from_buffer(key)
+        assert bytes(other) == key
+
         assert other == cipher
         assert other.export_key() == cipher.export_key() == key
         assert other.export_public_key() == cipher.export_public_key()
