@@ -4,7 +4,6 @@
 
 from __future__ import annotations
 
-import datetime as dt
 import errno
 import pickle
 import socket
@@ -13,20 +12,10 @@ import sys
 import time
 from contextlib import suppress
 from pathlib import Path
-from typing import (
-    Any,
-    Callable,
-    Iterator,
-    Mapping,
-    Optional,
-    Sequence,
-    Tuple,
-    Union,
-)
+from typing import Any, Callable, Iterator, Mapping, Sequence, Tuple, Union
 
 import pytest
 
-from mbedtls import hashlib
 from mbedtls._tls import (
     _SUPPORTED_DTLS_VERSION,
     _SUPPORTED_TLS_VERSION,
@@ -43,9 +32,6 @@ from mbedtls.tls import (
     DTLSVersion,
     HandshakeStep,
     HelloVerifyRequest,
-    MaxFragmentLength,
-    NextProtocol,
-    Purpose,
     ServerContext,
     TLSConfiguration,
     TLSRecordHeader,
@@ -56,9 +42,8 @@ from mbedtls.tls import (
     TrustStore,
     WantReadError,
     WantWriteError,
-    ciphers_available,
 )
-from mbedtls.x509 import CRT, CSR, BasicConstraints
+from mbedtls.x509 import CRT
 
 _Key = Union[RSA, ECC]
 _HostName = str
@@ -69,77 +54,36 @@ def rootpath() -> Path:
     return Path(__file__).parent.parent
 
 
-def make_root_ca(
-    # pylint: disable=too-many-arguments
-    subject: Optional[str] = None,
-    not_before: Optional[dt.datetime] = None,
-    not_after: Optional[dt.datetime] = None,
-    serial_number: Optional[int] = None,
-    basic_constraints: Optional[BasicConstraints] = None,
-    digestmod: Optional[hashlib.Algorithm] = None,
-) -> Tuple[CRT, _Key]:
-    if subject is None:
-        subject = "OU=test, CN=Trusted CA"
-    if not_before is None:
-        not_before = dt.datetime.utcnow()
-    if not_after is None:
-        not_after = not_before + dt.timedelta(days=90)
-    if serial_number is None:
-        serial_number = 0x123456
-    if basic_constraints is None:
-        basic_constraints = BasicConstraints(True, -1)
-    if digestmod is None:
-        digestmod = hashlib.sha256
-
-    key = RSA()
-    key.generate()
-    crt = CRT.selfsign(
-        csr=CSR.new(key, subject, digestmod()),
-        issuer_key=key,
-        not_before=not_before,
-        not_after=not_after,
-        serial_number=serial_number,
-        basic_constraints=basic_constraints,
-    )
-    return crt, key
+@pytest.fixture(scope="module")
+def assets(rootpath: Path) -> Path:
+    return rootpath / "tests" / "data"
 
 
-def make_crt(
-    # pylint: disable=too-many-arguments
-    issuer_crt: CRT,
-    issuer_key: _Key,
-    subject: Optional[str] = None,
-    not_before: Optional[dt.datetime] = None,
-    not_after: Optional[dt.datetime] = None,
-    serial_number: Optional[int] = None,
-    basic_constraints: Optional[BasicConstraints] = None,
-    digestmod: Optional[hashlib.Algorithm] = None,
-) -> Tuple[CRT, _Key]:
-    if subject is None:
-        subject = "OU=test, CN=hostname"
-    if not_before is None:
-        not_before = issuer_crt.not_before
-    if not_after is None:
-        not_after = issuer_crt.not_after
-    if serial_number is None:
-        serial_number = 0x123456
-    if basic_constraints is None:
-        basic_constraints = BasicConstraints()
-    if digestmod is None:
-        # TODO: issuer_crt.digestmod should work but doesn't.
-        digestmod = hashlib.sha256
+@pytest.fixture(scope="module")
+def ca_crt(assets: Path) -> CRT:
+    return CRT.from_file(assets / "ca.crt.pem")
 
-    key = RSA()
-    key.generate()
-    crt = issuer_crt.sign(
-        csr=CSR.new(key, subject, digestmod()),
-        issuer_key=issuer_key,
-        not_before=not_before,
-        not_after=not_after,
-        serial_number=serial_number,
-        basic_constraints=basic_constraints,
-    )
-    return crt, key
+
+@pytest.fixture(scope="module")
+def ca_key(assets: Path) -> _Key:
+    return RSA.from_file(assets / "ca.key.prv.pem")
+
+
+@pytest.fixture(scope="module")
+def ee_crt(assets: Path) -> CRT:
+    return CRT.from_file(assets / "ee.crt.pem")
+
+
+@pytest.fixture(scope="module")
+def ee_key(assets: Path) -> _Key:
+    return RSA.from_file(assets / "ee.key.prv.pem")
+
+
+@pytest.fixture(scope="module")
+def certificate_chain(
+    ca_crt: CRT, ee_crt: CRT, ee_key: _Key
+) -> Tuple[Tuple[CRT, ...], _Key]:
+    return (ee_crt, ca_crt), ee_key
 
 
 class TestPickle:
@@ -193,11 +137,11 @@ class TestPickle:
 
 
 class TestPSKStoreProxy:
-    @pytest.fixture()
+    @pytest.fixture
     def psk_store(self) -> Mapping[str, bytes]:
         return {"client": b"the secret key"}
 
-    @pytest.fixture()
+    @pytest.fixture
     def proxy(self, psk_store: Mapping[str, bytes]) -> PSKStoreProxy:
         return PSKStoreProxy(psk_store)
 
@@ -245,11 +189,11 @@ class TestTLSRecordHeader:
         assert isinstance(request.param, TLSVersion)
         return request.param
 
-    @pytest.fixture()
+    @pytest.fixture
     def length(self) -> int:
         return 42
 
-    @pytest.fixture()
+    @pytest.fixture
     def header(
         self,
         record_type: TLSRecordHeader.RecordType,
@@ -289,7 +233,7 @@ class TestTLSRecordHeader:
 
 
 class TestTLSSession:
-    @pytest.fixture()
+    @pytest.fixture
     def session(self) -> TLSSession:
         return TLSSession()
 
@@ -298,7 +242,7 @@ class TestTLSSession:
 
 
 class TestTrustStore:
-    @pytest.fixture()
+    @pytest.fixture
     def store(self) -> TrustStore:
         return TrustStore.system()
 
@@ -332,15 +276,14 @@ class TestTrustStore:
         store.add(store[0])
         assert len(store) == length
 
-    def test_add_new_certificate(self, store: TrustStore) -> None:
-        root_ca = make_root_ca()[0]
+    def test_add_new_certificate(self, store: TrustStore, ca_crt: CRT) -> None:
         length = len(store)
-        store.add(root_ca)
+        store.add(ca_crt)
         assert len(store) == length + 1
 
 
 class TestDTLSCookie:
-    @pytest.fixture()
+    @pytest.fixture
     def cookie(self) -> DTLSCookie:
         return DTLSCookie()
 
@@ -353,252 +296,6 @@ class TestDTLSCookie:
         assert cookie.timeout == 1000
 
 
-def assert_conf_invariant(
-    conf: Union[TLSConfiguration, DTLSConfiguration],
-    **elem: Any,
-) -> None:
-    # For the context, the configuration is converted into an
-    # internal MbedTLSConfiguration and the accessors then
-    # converts the MbedTLSConfiguration back into a
-    # TLSConfiguration (or DTLSConfiguration).  These conversions
-    # are what we actually check here.
-    __tracebackhide__ = True  # pylint: disable=unused-variable
-    assert len(elem) == 1
-
-    key, value = next(iter(elem.items()))
-    assert (
-        getattr(ServerContext(conf.update(**elem)).configuration, key) == value
-    )
-
-
-class TestConfiguration:
-    @pytest.fixture(params=[DTLSConfiguration, TLSConfiguration])
-    def conf(self, request: Any) -> Union[TLSConfiguration, DTLSConfiguration]:
-        conf = request.param()
-        assert isinstance(conf, (TLSConfiguration, DTLSConfiguration))
-        return conf
-
-    @pytest.mark.parametrize("validate", [True, False])
-    def test_set_validate_certificates(
-        self, conf: Union[TLSConfiguration, DTLSConfiguration], validate: bool
-    ) -> None:
-        assert_conf_invariant(conf, validate_certificates=validate)
-
-    def test_set_empty_certificate_chain(
-        self, conf: Union[TLSConfiguration, DTLSConfiguration]
-    ) -> None:
-        assert_conf_invariant(conf, certificate_chain=None)
-
-    def test_set_certificate_chain(
-        self, conf: Union[TLSConfiguration, DTLSConfiguration]
-    ) -> None:
-        root_crt, root_key = make_root_ca()
-        ee_crt, ee_key = make_crt(root_crt, root_key)
-        chain = (ee_crt, root_crt), ee_key
-        assert_conf_invariant(conf, certificate_chain=chain)
-
-    def test_set_ciphers(
-        self, conf: Union[TLSConfiguration, DTLSConfiguration]
-    ) -> None:
-        assert_conf_invariant(conf, ciphers=tuple(ciphers_available()))
-
-    @pytest.mark.parametrize(
-        "inner_protocols",
-        [
-            (),
-            (NextProtocol.H2, NextProtocol.H2C),
-            (NextProtocol.H2, NextProtocol.H2C, NextProtocol.FTP),
-        ],
-    )
-    def test_set_inner_protocols(
-        self,
-        conf: Union[TLSConfiguration, DTLSConfiguration],
-        inner_protocols: Tuple[Union[NextProtocol, bytes]],
-    ) -> None:
-        assert_conf_invariant(
-            conf,
-            inner_protocols=inner_protocols,
-        )
-
-    @pytest.mark.parametrize("trust_store", [TrustStore.system()])
-    def test_trust_store(
-        self,
-        conf: Union[TLSConfiguration, DTLSConfiguration],
-        trust_store: TrustStore,
-    ) -> None:
-        assert trust_store
-        assert_conf_invariant(conf, trust_store=trust_store)
-
-    @pytest.mark.parametrize("mfl", MaxFragmentLength)
-    def test_max_fragmentation_length(
-        self,
-        conf: Union[TLSConfiguration, DTLSConfiguration],
-        mfl: MaxFragmentLength,
-    ) -> None:
-        assert_conf_invariant(conf, max_fragmentation_length=mfl)
-
-    def test_set_sni_callback(
-        self,
-        conf: Union[TLSConfiguration, DTLSConfiguration],
-    ) -> None:
-        assert conf.sni_callback is None
-
-    @pytest.mark.parametrize("psk", [None, ("client", b"the secret key")])
-    def test_psk(
-        self,
-        conf: Union[TLSConfiguration, DTLSConfiguration],
-        psk: Tuple[str, bytes],
-    ) -> None:
-        assert conf.pre_shared_key is None
-        assert_conf_invariant(conf, pre_shared_key=psk)
-
-    @pytest.mark.parametrize("psk_store", [{}, {"client": b"the secret key"}])
-    def test_psk_store(
-        self,
-        conf: Union[TLSConfiguration, DTLSConfiguration],
-        psk_store: Mapping[str, bytes],
-    ) -> None:
-        assert not conf.pre_shared_key_store
-        assert_conf_invariant(conf, pre_shared_key_store=psk_store)
-
-
-class TestTLSConfiguration:
-    @pytest.fixture()
-    def conf(self) -> TLSConfiguration:
-        return TLSConfiguration()
-
-    def test_default_supported_versions(self, conf: TLSConfiguration) -> None:
-        assert conf.lowest_supported_version is TLSVersion.TLSv1
-        assert conf.highest_supported_version is TLSVersion.MAXIMUM_SUPPORTED
-
-    @pytest.mark.parametrize("version", _SUPPORTED_TLS_VERSION)
-    def test_lowest_supported_version(
-        self, conf: TLSConfiguration, version: TLSVersion
-    ) -> None:
-        assert_conf_invariant(conf, lowest_supported_version=version)
-
-    @pytest.mark.parametrize("version", _SUPPORTED_TLS_VERSION)
-    def test_highest_supported_version(
-        self, conf: TLSConfiguration, version: TLSVersion
-    ) -> None:
-        assert_conf_invariant(conf, highest_supported_version=version)
-
-
-class TestDTLSConfiguration:
-    @pytest.fixture()
-    def conf(self) -> DTLSConfiguration:
-        return DTLSConfiguration()
-
-    def test_default_supported_versions(self, conf: DTLSConfiguration) -> None:
-        assert conf.lowest_supported_version is DTLSVersion.DTLSv1_0
-        assert conf.highest_supported_version is DTLSVersion.MAXIMUM_SUPPORTED
-
-    @pytest.mark.parametrize("version", _SUPPORTED_DTLS_VERSION)
-    def test_lowest_supported_version(
-        self, conf: DTLSConfiguration, version: DTLSVersion
-    ) -> None:
-        assert_conf_invariant(conf, lowest_supported_version=version)
-
-    @pytest.mark.parametrize("version", _SUPPORTED_DTLS_VERSION)
-    def test_highest_supported_version(
-        self, conf: DTLSConfiguration, version: DTLSVersion
-    ) -> None:
-        assert_conf_invariant(conf, highest_supported_version=version)
-
-    @pytest.mark.parametrize("anti_replay", [True, False])
-    def test_set_anti_replay(
-        self, conf: DTLSConfiguration, anti_replay: bool
-    ) -> None:
-        assert conf.anti_replay is True
-        assert_conf_invariant(conf, anti_replay=anti_replay)
-
-    @pytest.mark.parametrize(
-        "hs_min_max", [(1, 60), (42, 69), (4.2, 6.9), (42.0, 69.0)]
-    )
-    def test_handshake_timeout_minmax(
-        self,
-        conf: DTLSConfiguration,
-        hs_min_max: Tuple[float, float],
-    ) -> None:
-        hs_min, hs_max = hs_min_max
-        assert conf.handshake_timeout_min == 1.0
-        assert conf.handshake_timeout_max == 60.0
-        conf_ = conf.update(
-            handshake_timeout_min=hs_min,
-            handshake_timeout_max=hs_max,
-        )
-        assert conf_.handshake_timeout_min == hs_min
-        assert conf_.handshake_timeout_max == hs_max
-
-        assert_conf_invariant(conf, handshake_timeout_min=hs_min)
-        assert_conf_invariant(conf, handshake_timeout_max=hs_max)
-
-    @pytest.mark.parametrize("hs_min_max", [(1, 60), (42, 69), (4.2, 6.9)])
-    def test_handshake_timeout_default(
-        self,
-        conf: DTLSConfiguration,
-        hs_min_max: Tuple[float, float],
-    ) -> None:
-        assert conf.handshake_timeout_min == 1.0
-        assert conf.handshake_timeout_max == 60.0
-
-        hs_min, hs_max = hs_min_max
-        conf_ = conf.update(
-            handshake_timeout_min=hs_min,
-            handshake_timeout_max=hs_max,
-        )
-        assert conf_.handshake_timeout_min == hs_min
-        assert conf_.handshake_timeout_max == hs_max
-
-        assert_conf_invariant(conf, handshake_timeout_min=hs_min)
-        assert_conf_invariant(conf, handshake_timeout_max=hs_max)
-
-    @pytest.mark.parametrize("timeout", [1, 10, 5.3, 300])
-    def test_read_timeout_default(
-        self,
-        conf: Union[TLSConfiguration, DTLSConfiguration],
-        timeout: float,
-    ) -> None:
-        assert conf.read_timeout == 0
-        conf_ = conf.update(
-            read_timeout=timeout,
-        )
-        assert conf_.read_timeout == timeout
-
-        assert_conf_invariant(conf, read_timeout=timeout)
-
-
-class TestContext:
-    @pytest.fixture(params=[Purpose.SERVER_AUTH, Purpose.CLIENT_AUTH])
-    def purpose(self, request: Any) -> Purpose:
-        assert isinstance(request.param, Purpose)
-        return request.param
-
-    @pytest.fixture(params=[TLSConfiguration, DTLSConfiguration])
-    def conf(self, request: Any) -> Union[TLSConfiguration, DTLSConfiguration]:
-        conf = request.param()
-        assert isinstance(conf, (TLSConfiguration, DTLSConfiguration))
-        return conf
-
-    @pytest.fixture(params=[ServerContext, ClientContext])
-    def context(
-        self, conf: Union[TLSConfiguration, DTLSConfiguration], request: Any
-    ) -> Union[ServerContext, ClientContext]:
-        ctx = request.param(conf)
-        assert isinstance(ctx, (ServerContext, ClientContext))
-        return ctx
-
-    def test_repr(self, context: Union[ServerContext, ClientContext]) -> None:
-        assert isinstance(repr(context), str)
-
-    def test_get_configuration(
-        self,
-        context: Union[ServerContext, ClientContext],
-        conf: Union[TLSConfiguration, DTLSConfiguration],
-    ) -> None:
-        assert context.configuration == conf
-
-
 CLIENT_HELLO = (HandshakeStep.CLIENT_HELLO,)
 SERVER_HELLO = (
     HandshakeStep.SERVER_HELLO,
@@ -731,16 +428,6 @@ class TestTLSHandshake:
     def hostname(self) -> _HostName:
         return "www.example.com"
 
-    @pytest.fixture(scope="class")
-    def certificate_chain(
-        self, hostname: _HostName
-    ) -> Tuple[Tuple[CRT, ...], _Key]:
-        root_crt, root_key = make_root_ca()
-        ee_crt, ee_key = make_crt(
-            root_crt, root_key, subject=f"OU=test, CN={hostname}"
-        )
-        return (ee_crt, root_crt), ee_key
-
     def test_cert_without_validation(
         self, certificate_chain: Tuple[Tuple[CRT, ...], _Key]
     ) -> None:
@@ -902,7 +589,7 @@ class TestWrappedSocket_SmokeTests:
             pass
 
 
-@pytest.mark.e2e()
+@pytest.mark.e2e
 @pytest.mark.skipif(sys.platform == "win32", reason="Flaky under Windows")
 class TestProgramsTLS:
     @pytest.fixture(scope="class")
@@ -1032,7 +719,7 @@ class TestProgramsTLS:
         assert excinfo.value.errno is errno.ENOTCONN
 
 
-@pytest.mark.e2e()
+@pytest.mark.e2e
 @pytest.mark.skipif(sys.platform == "win32", reason="Flaky under Windows")
 class TestProgramsDTLS:
     @pytest.fixture(scope="class")
